==> yuview_2.9.orig.tar.gz: YUView-2.9/YUViewLib/src/ui/widgets/QLabelClickable.h <==
/*  This file is part of YUView - The YUV player with advanced analytics toolset
*   <https://github.com/IENT/YUView>
*   Copyright (C) 2015  Institut für Nachrichtentechnik, RWTH Aachen University, GERMANY
*
*   This program is free software; you can redistribute it and/or modify
*   it under the terms of the GNU General Public License as published by
*   the Free Software Foundation; either version 3 of the License, or
*   (at your option) any later version.
*
*   In addition, as a special exception, the copyright holders give
*   permission to link the code of portions of this program with the
*   OpenSSL library under certain conditions as described in each
*   individual source file, and distribute linked combinations including
*   the two.
*   
*   You must obey the GNU General Public License in all respects for all
*   of the code used other than OpenSSL. If you modify file(s) with this
*   exception, you may extend this exception to your version of the
*   file(s), but you are not obligated to do so. If you do not wish to do
*   so, delete this exception statement from your version. If you delete
*   this exception statement from all source files in the program, then
*   also delete it here.
*
*   This program is distributed in the hope that it will be useful,
*   but WITHOUT ANY WARRANTY; without even the implied warranty of
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
*   GNU General Public License for more details.
*
*   You should have received a copy of the GNU General Public License
*   along with this program. If not, see <http://www.gnu.org/licenses/>.
*/

#include <QLabel>

// A label that emits a 'clicked' signal when clicked.
class QLabelClickable : public QLabel
{
  Q_OBJECT

public:
  QLabelClickable(QWidget *parent) : QLabel(parent) { pressed = false; }
  virtual void mousePressEvent(QMouseEvent *event)
  {
    Q_UNUSED(event);
    pressed = true;
  }
  virtual void mouseReleaseEvent(QMouseEvent *event)
  {
    Q_UNUSED(event);
    if (pressed)
      // The mouse was pressed and is now released.
      emit clicked();
    pressed = false;
  }
signals:
  void clicked();
private:
  bool pressed;
};

==> yuview_2.14.orig.tar.gz: YUView-2.14/YUViewLib/src/ui/widgets/QLabelClickable.h <==
/*  This file is part of YUView - The YUV player with advanced analytics toolset
*   <https://github.com/IENT/YUView>
*   Copyright (C) 2015  Institut für Nachrichtentechnik, RWTH Aachen University, GERMANY
*
*   This program is free software; you can redistribute it and/or modify
*   it under the terms of the GNU General Public License as published by
*   the Free Software Foundation; either version 3 of the License, or
*   (at your option) any later version.
*
*   In addition, as a special exception, the copyright holders give
*   permission to link the code of portions of this program with the
*   OpenSSL library under certain conditions as described in each
*   individual source file, and distribute linked combinations including
*   the two.
*   
*   You must obey the GNU General Public License in all respects for all
*   of the code used other than OpenSSL. If you modify file(s) with this
*   exception, you may extend this exception to your version of the
*   file(s), but you are not obligated to do so. If you do not wish to do
*   so, delete this exception statement from your version. If you delete
*   this exception statement from all source files in the program, then
*   also delete it here.
*
*   This program is distributed in the hope that it will be useful,
*   but WITHOUT ANY WARRANTY; without even the implied warranty of
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
*   GNU General Public License for more details.
*
*   You should have received a copy of the GNU General Public License
*   along with this program. If not, see <http://www.gnu.org/licenses/>.
*/

#include <QLabel>

// A label that emits a 'clicked' signal when clicked.
class QLabelClickable : public QLabel
{
  Q_OBJECT

public:
  QLabelClickable(QWidget *parent) : QLabel(parent) { this->pressed = false; }
  virtual void mousePressEvent(QMouseEvent *)
  {
    this->pressed = true;
  }
  virtual void mouseReleaseEvent(QMouseEvent *)
  {
    if (this->pressed)
      // The mouse was pressed and is now released.
      emit clicked();
    this->pressed = false;
  }
signals:
  void clicked();
private:
  bool pressed;
};
